lilypondfiletools.LilyPondDimension
===================================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.storage_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.unit
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.value
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension.LilyPondDimension.__repr__
   :noindex:
